@@ -9,7 +9,7 @@
 (defparameter *autoconf-libexecdir* "/opt/local/libexec")
 (defparameter *autoconf-datadir* "/opt/local/share")
 (defparameter *autoconf-infodir* "/opt/local/share/info")
-(defparameter *autoconf-host* "arm-apple-darwin24.3.0")
+(defparameter *autoconf-host* "arm-apple-darwin24.6.0")
 ;; This variable is kept for backwards compatibility reasons:
 ;; We seem to be in the fortunate position that we sometimes need to check for windows.
 ;; But at least until dec 2015 we didn't need to check for a specific windows flavour.
@@ -20,5 +20,5 @@
 ;; This will be T if this was a lisp-only build
 (defparameter *autoconf-lisp-only-build* (eq t 'nil))
  
-(defparameter *maxima-source-root* "/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_math_maxima/maxima/work/maxima-5.47.0")
+(defparameter *maxima-source-root* "/opt/local/var/macports/build/maxima-0dc76224/work/maxima-5.47.0")
 (defparameter *maxima-default-layout-autotools* "true")
